@@ -6,12 +6,14 @@ describe 'tacker::client' do
 
     context 'with default parameters' do
       it 'contains tacker::params' do
+          is_expected.to contain_class('tacker::deps')
           is_expected.to contain_class('tacker::params')
       end
       it 'contains tackerclient' do
           is_expected.to contain_package('python-tackerclient').with(
               :ensure => 'present',
-              :name   => platform_params[:tackerclient_package]
+              :name   => platform_params[:client_package_name],
+              :tag    => 'openstack',
           )
       end
     end
@@ -29,11 +31,12 @@ describe 'tacker::client' do
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          { :tackerclient_package => 'python-tackerclient' }
+          { :client_package_name => 'python3-tackerclient' }
         when 'RedHat'
-          { :tackerclient_package => 'python-tackerclient' }
+          { :client_package_name => 'python-tackerclient' }
         end
       end
+
       it_behaves_like 'tacker::client'
 
     end
